/*! 'francy-extension-jupyter, v1.0.3, A package for rendering application/vnd.francy+json in Jupyter, Manuel Martins <manuelmachadomartins@gmail.com>.' */
define(["base/js/namespace","nbextensions/jupyter_francy/index"],function(e,n){return function(e){var n={};function r(t){if(n[t]){return n[t].exports}var o=n[t]={i:t,l:false,exports:{}};e[t].call(o.exports,o,o.exports,r);o.l=true;return o.exports}r.m=e;r.c=n;r.d=function(e,n,t){if(!r.o(e,n)){Object.defineProperty(e,n,{enumerable:true,get:t})}};r.r=function(e){if(typeof Symbol!=="undefined"&&Symbol.toStringTag){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"})}Object.defineProperty(e,"__esModule",{value:true})};r.t=function(e,n){if(n&1)e=r(e);if(n&8)return e;if(n&4&&typeof e==="object"&&e&&e.__esModule)return e;var t=Object.create(null);r.r(t);Object.defineProperty(t,"default",{enumerable:true,value:e});if(n&2&&typeof e!="string")for(var o in e)r.d(t,o,function(n){return e[n]}.bind(null,o));return t};r.n=function(e){var n=e&&e.__esModule?function n(){return e["default"]}:function n(){return e};r.d(n,"a",n);return n};r.o=function(e,n){return Object.prototype.hasOwnProperty.call(e,n)};r.p="";return r(r.s=0)}([function(e,n,r){var t,o;if(window.require){window.require.config({map:{"*":{jupyter_francy:"nbextensions/jupyter_francy/index"}}})}!(t=[r(1),r(2)],o=function(e,n){function r(){var r=e.notebook;n.init(e);n.register_renderer(r);n.render_cells(r)}return{load_ipython_extension:r}}.apply(n,t),o!==undefined&&(e.exports=o))},function(n,r){n.exports=e},function(e,r){e.exports=n}])});